import { trigger, state, style, transition, group, animate, query } from '@angular/animations';

const ColorTransitionAnimation = trigger('colorTransition', [
    state('color1', style({
        'background': "{{ color1 }}",
    }), {
        params: {
            color1: '#000',
        }
    }),
    state('color2', style({
        'background': "{{ color2 }}",
    }), {
        params: {
            color2: '#444',
        }
    }),
    transition('color1 => color2', [
        group([
            animate('{{ duration }} ease-in-out', style({
                'background': "{{ color2 }}"
            })),
        ])
    ], {
        params: {
            color1: '#000',
            color2: '#444',
            duration: '1s',
        }
    }),
    transition('color2 => color1', [
        group([
            animate('{{ duration }} ease-in-out', style({
                'background': "{{ color1 }}"
            })),
        ])
    ], {
        params: {
            color1: '#000',
            color2: '#444',
            duration: '1s',
        }
    }),
]);

const FadeInOutAnimation = trigger('fadeInOut', [
    transition(':enter', [
        style({ opacity: 0 }),
        animate('500ms', style({ opacity: 1 })),
    ]),
    transition(':leave', [
        animate('500ms', style({ opacity: 0 }))
    ]),
]);

const CarouselSlideAnimation = trigger('carouselSlide', [
    // Previous, slide left to right to show left page
    transition(':decrement', [
        // set new page X location to be -100%
        query(':enter', style({ width: '100%', transform: 'translateX(-100%)' })),
        group([
            // slide existing page from 0% to 100% to the right
            query(':leave', animate('500ms ease', style({ width: '100%', transform: 'translateX(100%)' }))),
            // slide new page from -100% to 0% to the right
            query(':enter', animate('500ms ease', style({ opacity: 1, transform: 'translateX(0%)' }))),
        ]),
    ]),
    // Next, slide right to left to show right page
    transition(':increment', [
        // set new page X location to be 100%
        query(':enter', style({ width: '100%', transform: 'translateX(100%)' })),
        group([
            // slide existing page from 0% to -100% to the left
            query(':leave', animate('500ms ease', style({ width: '100%', transform: 'translateX(-100%)' }))),
            // slide new page from 100% to 0% to the left
            query(':enter', animate('500ms ease', style({ opacity: 1, transform: 'translateX(0%)' }))),
        ]),
    ])
]);

const SlideUpDownAnimation = trigger('slideUpDown', [
    transition(':enter', [
        style({ height: 0 }),
        animate('300ms ease-in-out', style({ height: '*' })),
    ]),
    transition(':leave', [
        style({ height: '*' }),
        animate('300ms ease-in-out', style({ height: 0 })),
    ]),
]);

/**
 * Generated bundle index. Do not edit.
 */

export { CarouselSlideAnimation, ColorTransitionAnimation, FadeInOutAnimation, SlideUpDownAnimation };
//# sourceMappingURL=mintplayer-ng-animations.mjs.map
